@@ -27,7 +27,7 @@ import org.videolan.libvlc.util.HWDecoderUtil;
 
 import java.io.FileDescriptor;
 
-@SuppressWarnings("unused")
+@SuppressWarnings("unused, JniMissingFunction")
 public class Media extends VLCObject<Media.Event> {
     private final static String TAG = "LibVLC/Media";
 
@@ -121,6 +121,7 @@ public class Media extends VLCObject<Media.Event> {
         public static final int ParseNetwork = 0x01;
         public static final int FetchLocal   = 0x02;
         public static final int FetchNetwork = 0x04;
+        public static final int DoInteract   = 0x08;
     }
 
     /**
@@ -207,7 +208,7 @@ public class Media extends VLCObject<Media.Event> {
         }
     }
 
-    /* Used from JNI */
+    @SuppressWarnings("unused") /* Used from JNI */
     private static Track createVideoTrackFromNative(String codec, String originalCodec, int id, int profile,
             int level, int bitrate, String language, String description,
             int height, int width, int sarNum, int sarDen, int frameRateNum, int frameRateDen) {
@@ -239,6 +240,23 @@ public class Media extends VLCObject<Media.Event> {
                 encoding);
     }
 
+    /**
+     * see libvlc_subtitle_track_t
+     */
+    public static class UnknownTrack extends Track {
+        private UnknownTrack(String codec, String originalCodec, int id, int profile,
+                             int level, int bitrate, String language, String description) {
+            super(Type.Unknown, codec, originalCodec, id, profile, level, bitrate, language, description);
+        }
+    }
+
+    @SuppressWarnings("unused") /* Used from JNI */
+    private static Track createUnknownTrackFromNative(String codec, String originalCodec, int id, int profile,
+                                                      int level, int bitrate, String language, String description) {
+        return new UnknownTrack(codec, originalCodec, id, profile,
+                level, bitrate, language, description);
+    }
+
     private static final int PARSE_STATUS_INIT = 0x00;
     private static final int PARSE_STATUS_PARSING = 0x01;
     private static final int PARSE_STATUS_PARSED = 0x02;
