@@ -366,10 +366,8 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                     case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT:
                         Log.i(TAG, "AUDIOFOCUS_LOSS_TRANSIENT");
                         // Pause playback
-                        if (mMediaPlayer.isPlaying()) {
-                            mLossTransient = true;
-                            mMediaPlayer.pause();
-                        }
+                        mLossTransient = true;
+                        mMediaPlayer.pause();
                         break;
                     case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT_CAN_DUCK:
                         Log.i(TAG, "AUDIOFOCUS_LOSS_TRANSIENT_CAN_DUCK");
@@ -469,7 +467,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
              * Remote / headset control events
              */
             if (action.equalsIgnoreCase(ACTION_REMOTE_PLAYPAUSE)) {
-                if (mMediaPlayer.isPlaying() && hasCurrentMedia())
+                if (hasCurrentMedia())
                     pause();
                 else if (!mMediaPlayer.isPlaying() && hasCurrentMedia())
                     play();
@@ -477,7 +475,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                 if (!mMediaPlayer.isPlaying() && hasCurrentMedia())
                     play();
             } else if (action.equalsIgnoreCase(ACTION_REMOTE_PAUSE)) {
-                if (mMediaPlayer.isPlaying() && hasCurrentMedia())
+                if (hasCurrentMedia())
                     pause();
             } else if (action.equalsIgnoreCase(ACTION_REMOTE_BACKWARD)) {
                 previous();
@@ -502,12 +500,12 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
             if (mDetectHeadset && !mHasHdmiAudio) {
                 if (action.equalsIgnoreCase(AudioManager.ACTION_AUDIO_BECOMING_NOISY)) {
                     Log.i(TAG, "Headset Removed.");
-                    if (mMediaPlayer.isPlaying() && hasCurrentMedia())
+                    if (hasCurrentMedia())
                         pause();
                 }
                 else if (action.equalsIgnoreCase(Intent.ACTION_HEADSET_PLUG) && state != 0) {
                     Log.i(TAG, "Headset Inserted.");
-                    if (!mMediaPlayer.isPlaying() && hasCurrentMedia())
+                    if (hasCurrentMedia())
                         play();
                 }
             }
@@ -1186,7 +1184,6 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
 
         mPrevious.push(mCurrentIndex);
         mCurrentIndex = mNextIndex;
-        Log.d(TAG, "setting current to " + mCurrentIndex);
         if (size == 0 || mCurrentIndex < 0 || mCurrentIndex >= size) {
             if (mCurrentIndex < 0)
                 saveCurrentMedia();
@@ -1765,7 +1762,6 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     public void moveItem(int positionStart, int positionEnd) {
         mMediaList.move(positionStart, positionEnd);
         PlaybackService.this.saveMediaList();
-        Log.d(TAG, "moveItem " + positionStart + " -> " + positionEnd);
     }
 
     @MainThread
@@ -1781,7 +1777,6 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         mMediaList.remove(position);
         saveMediaList();
         determinePrevAndNextIndices();
-        Log.d(TAG, "remove "+position);
     }
 
     @MainThread
@@ -2037,7 +2032,6 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         private final ServiceConnection mServiceConnection = new ServiceConnection() {
             @Override
             public void onServiceConnected(ComponentName name, IBinder iBinder) {
-                Log.d(TAG, "Service Connected");
                 if (!mBound)
                     return;
 
@@ -2048,7 +2042,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
 
             @Override
             public void onServiceDisconnected(ComponentName name) {
-                Log.d(TAG, "Service Disconnected");
+                mBound = false;
                 mCallback.onDisconnected();
             }
         };
