@@ -23,28 +23,36 @@
 
 package org.videolan.vlc.gui;
 
+import android.content.Intent;
 import android.os.Bundle;
 import android.support.v4.app.Fragment;
 import android.view.Menu;
 import android.view.MenuItem;
 
-import org.videolan.vlc.media.MediaLibrary;
-import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.R;
+import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.audio.AudioAlbumFragment;
 import org.videolan.vlc.gui.audio.AudioAlbumsSongsFragment;
 import org.videolan.vlc.gui.audio.EqualizerFragment;
 import org.videolan.vlc.gui.browser.StorageBrowserFragment;
+import org.videolan.vlc.gui.preferences.PreferencesActivity;
 import org.videolan.vlc.gui.video.MediaInfoFragment;
 import org.videolan.vlc.gui.video.VideoGridFragment;
 import org.videolan.vlc.gui.video.VideoListAdapter;
 import org.videolan.vlc.interfaces.ISortable;
+import org.videolan.vlc.media.MediaLibrary;
+import org.videolan.vlc.media.MediaWrapper;
 
 import java.util.ArrayList;
 
 public class SecondaryActivity extends AudioPlayerContainerActivity {
     public final static String TAG = "VLC/SecondaryActivity";
 
+    public static final int ACTIVITY_RESULT_SECONDARY = 3;
+
+    public static final String KEY_FRAGMENT = "fragment";
+    public static final String KEY_FILTER = "filter";
+
     public static final String ALBUMS_SONGS = "albumsSongs";
     public static final String ALBUM = "album";
     public static final String EQUALIZER = "equalizer";
@@ -64,7 +72,7 @@ public class SecondaryActivity extends AudioPlayerContainerActivity {
         mActionBar.setDisplayHomeAsUpEnabled(true);
 
         if (getSupportFragmentManager().getFragments() == null) {
-            String fragmentId = getIntent().getStringExtra("fragment");
+            String fragmentId = getIntent().getStringExtra(KEY_FRAGMENT);
             fetchSecondaryFragment(fragmentId);
             if (mFragment == null){
                 finish();
@@ -89,6 +97,16 @@ public class SecondaryActivity extends AudioPlayerContainerActivity {
         super.onPause();
     }
 
+    @Override
+    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
+        super.onActivityResult(requestCode, resultCode, data);
+        if (requestCode == ACTIVITY_RESULT_SECONDARY) {
+            if (resultCode == PreferencesActivity.RESULT_RESCAN) {
+                MediaLibrary.getInstance().scanMediaItems(true);
+            }
+        }
+    }
+
     @Override
     public boolean onCreateOptionsMenu(Menu menu) {
         if (mFragment instanceof VideoGridFragment)
@@ -124,13 +142,13 @@ public class SecondaryActivity extends AudioPlayerContainerActivity {
 
     public void fetchSecondaryFragment(String id) {
         if (id.equals(ALBUMS_SONGS)) {
-            ArrayList<MediaWrapper> mediaList = getIntent().getParcelableArrayListExtra("list");
-            String filter = getIntent().getStringExtra("filter");
+            ArrayList<MediaWrapper> mediaList = (ArrayList<MediaWrapper>) VLCApplication.getData(ALBUMS_SONGS);
+            String filter = getIntent().getStringExtra(KEY_FILTER);
             mFragment = new AudioAlbumsSongsFragment();
             ((AudioAlbumsSongsFragment) mFragment).setMediaList(mediaList, filter);
         } else if(id.equals(ALBUM)) {
-            ArrayList<MediaWrapper> mediaList = getIntent().getParcelableArrayListExtra("list");
-            String filter = getIntent().getStringExtra("filter");
+            ArrayList<MediaWrapper> mediaList = (ArrayList<MediaWrapper>) VLCApplication.getData(ALBUM);
+            String filter = getIntent().getStringExtra(KEY_FILTER);
             mFragment = new AudioAlbumFragment();
             ((AudioAlbumFragment) mFragment).setMediaList(mediaList, filter);
         } else if(id.equals(EQUALIZER)) {
