@@ -45,6 +45,7 @@ import android.view.ViewGroup;
 import android.widget.TextView;
 
 import org.videolan.libvlc.Media;
+import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.libvlc.util.MediaBrowser;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
@@ -87,6 +88,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     protected MediaWrapper mCurrentMedia;
     protected int mSavedPosition = -1, mFavorites = 0;
     public boolean mRoot;
+    boolean goBack = false;
 
     private SparseArray<ArrayList<MediaWrapper>> mFoldersContentLists;
     private ArrayList<MediaWrapper> mediaList;
@@ -147,6 +149,13 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         return v;
     }
 
+    @Override
+    public void onResume() {
+        super.onResume();
+        if (goBack)
+            goBack();
+    }
+
     public void onStop(){
         super.onStop();
         releaseBrowser();
@@ -234,6 +243,8 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         mHandler.sendEmptyMessage(BrowserFragmentHandler.MSG_HIDE_LOADING);
         if (mReadyToDisplay)
             display();
+        if (!isResumed())
+            goBack = true;
     }
 
     @Override
@@ -343,6 +354,8 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         @Override
         public void handleMessage(Message msg) {
             BaseBrowserFragment fragment = getOwner();
+            if (fragment == null)
+                return;
             switch (msg.what){
                 case MSG_SHOW_LOADING:
                     fragment.mSwipeRefreshLayout.setRefreshing(true);
@@ -472,8 +485,9 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
             }
             case R.id.directory_view_play_folder:
                 ArrayList<MediaWrapper> mediaList = new ArrayList<MediaWrapper>();
+                boolean videoPlaylist = AndroidUtil.isHoneycombOrLater();
                 for (MediaWrapper mediaItem : mFoldersContentLists.get(position)){
-                    if (mediaItem.getType() == MediaWrapper.TYPE_AUDIO || mediaItem.getType() == MediaWrapper.TYPE_VIDEO)
+                    if (mediaItem.getType() == MediaWrapper.TYPE_AUDIO || (videoPlaylist && mediaItem.getType() == MediaWrapper.TYPE_VIDEO))
                         mediaList.add(mediaItem);
                 }
                 MediaUtils.openList(getActivity(), mediaList, 0);
