@@ -29,6 +29,8 @@ import android.graphics.drawable.BitmapDrawable;
 import android.graphics.drawable.Drawable;
 import android.net.Uri;
 import android.os.Build;
+import android.os.Handler;
+import android.os.Looper;
 import android.support.v17.leanback.widget.ImageCardView;
 import android.support.v17.leanback.widget.Presenter;
 import android.text.TextUtils;
@@ -56,6 +58,7 @@ public class CardPresenter extends Presenter {
     private static int CARD_HEIGHT = 0;
     private static MediaDatabase sMediaDatabase = MediaDatabase.getInstance();
     private static Drawable sDefaultCardImage;
+    private static Handler sHandler = new Handler(Looper.getMainLooper());
 
     public CardPresenter(Activity context){
         mContext = context;
@@ -78,8 +81,13 @@ public class CardPresenter extends Presenter {
         }
 
         protected void updateCardViewImage(MediaWrapper mediaWrapper) {
-            mCardView.getMainImageView().setScaleType(ImageView.ScaleType.CENTER);
-            AsyncImageLoader.LoadImage(new CoverFetcher(mContext, mediaWrapper), mCardView);
+            if (!TextUtils.isEmpty(mediaWrapper.getArtworkURL()) && mediaWrapper.getArtworkURL().startsWith("http")) {
+                mCardView.getMainImageView().setScaleType(ImageView.ScaleType.FIT_CENTER);
+                AsyncImageLoader.LoadImage(new HttpImageLoader(mediaWrapper.getArtworkURL()), mCardView);
+            } else {
+                mCardView.getMainImageView().setScaleType(mediaWrapper.getType() == MediaWrapper.TYPE_DIR ? ImageView.ScaleType.CENTER : ImageView.ScaleType.CENTER_CROP);
+                AsyncImageLoader.LoadImage(new CoverFetcher(mContext, mediaWrapper), mCardView);
+            }
         }
 
         protected void updateCardViewImage(Drawable image) {
@@ -121,9 +129,11 @@ public class CardPresenter extends Presenter {
             SimpleCard card = (SimpleCard) item;
             Bitmap image = card.getImage();
             holder.mCardView.setTitleText(card.getName());
+            holder.mCardView.setContentText("");
             holder.updateCardViewImage(image != null ? new BitmapDrawable(image) : mRes.getDrawable(card.getImageId()));
         }else if (item instanceof String){
             holder.mCardView.setTitleText((String) item);
+            holder.mCardView.setContentText("");
             holder.updateCardViewImage(sDefaultCardImage);
         }
     }
@@ -235,9 +245,7 @@ public class CardPresenter extends Presenter {
 
         @Override
         public void updateImage(final Bitmap picture, final View target) {
-            if (!TextUtils.isEmpty(mediaWrapper.getArtworkURL()) && mediaWrapper.getArtworkURL().startsWith("http"))
-                AsyncImageLoader.LoadImage(new HttpImageLoader(mediaWrapper.getArtworkURL()), target);
-            context.runOnUiThread(
+            sHandler.post(
                     new Runnable() {
                         @Override
                         public void run() {
