@@ -27,6 +27,7 @@ import android.content.pm.PackageManager;
 import android.content.pm.ResolveInfo;
 
 import org.videolan.libvlc.util.AndroidUtil;
+import org.videolan.libvlc.util.MediaBrowser;
 import org.videolan.vlc.VLCApplication;
 
 import java.io.BufferedReader;
@@ -74,16 +75,12 @@ public class Util {
     }
 
     public static boolean close(Closeable closeable) {
-        if (closeable != null) {
+        if (closeable != null)
             try {
                 closeable.close();
                 return true;
-            } catch (IOException e) {
-                return false;
-            }
-        } else {
-            return false;
-        }
+            } catch (IOException e) {}
+        return false;
     }
 
     public static boolean isCallable(Intent intent) {
